pub struct Skip(pub usize);Expand description
A future that skips a fixed number of executor polling cycles.
Useful for low-priority tasks that do not need to check their state on every single tick of the executor.
Example
async fn background_task() {
loop {
// Only run once every 10 scheduler passes
Skip(10).await;
check_background_logs();
}
}Tuple Fields
0: usizeTrait Implementations