pub struct Yield;Expand description
A unit structure that implements IntoFuture for a clean .await syntax.
Using Yield.await is the preferred way to cooperatively yield control back
to the [Executor]. It ensures other tasks (like input handling) can run.
Example
async fn heavy_computation() {
for i in 0..1000 {
do_work(i);
// Yield every iteration to prevent system hang
Yield.await;
}
}Trait Implementations
Sourceimpl IntoFuture for Yield
impl IntoFuture for Yield
Sourcetype IntoFuture = _Yield
type IntoFuture = _Yield
Which kind of future are we turning this into?
Sourcefn into_future(self) -> Self::IntoFuture
fn into_future(self) -> Self::IntoFuture
Creates a future from a value. Read more