Enumerate

Struct Enumerate 

pub struct Enumerate<CS>
where CS: ConcurrentStream,
{ /* private fields */ }
Available on crate features nano-alloc and alloc only.
A concurrent iterator that yields the current count and the element during iteration.

This struct is created by the enumerate method on ConcurrentStream. See its documentation for more.