pub struct FutureGroup<F> { /* private fields */ }Available on crate feature
nano-alloc only.Expand description
A growable group of futures which act as a single unit.
Example
Basic example
use futures_concurrency::future::FutureGroup;
use futures_lite::StreamExt;
use std::future;
let mut group = FutureGroup::new();
group.insert(future::ready(2));
group.insert(future::ready(4));
let mut out = 0;
while let Some(num) = group.next().await {
out += num;
}
assert_eq!(out, 6);Update the group on every iteration
use futures_concurrency::future::FutureGroup;
use lending_stream::prelude::*;
use std::future;
let mut group = FutureGroup::new();
group.insert(future::ready(4));
let mut index = 3;
let mut out = 0;
let mut group = group.lend_mut();
while let Some((group, num)) = group.next().await {
if index != 0 {
group.insert(future::ready(index));
index -= 1;
}
out += num;
}
assert_eq!(out, 10);Implementations
Sourceimpl<F> FutureGroup<F>
impl<F> FutureGroup<F>
Sourcepub fn new() -> FutureGroup<F>
Available on crate feature alloc only.
pub fn new() -> FutureGroup<F>
alloc only.Create a new instance of FutureGroup.
Example
use futures_concurrency::future::FutureGroup;
let group = FutureGroup::new();Sourcepub fn with_capacity(capacity: usize) -> FutureGroup<F>
Available on crate feature alloc only.
pub fn with_capacity(capacity: usize) -> FutureGroup<F>
alloc only.Create a new instance of FutureGroup with a given capacity.
Example
use futures_concurrency::future::FutureGroup;
let group = FutureGroup::with_capacity(2);Sourcepub fn len(&self) -> usize
Available on crate feature alloc only.
pub fn len(&self) -> usize
alloc only.Return the number of futures currently active in the group.
Example
use futures_concurrency::future::FutureGroup;
use futures_lite::StreamExt;
use std::future;
let mut group = FutureGroup::with_capacity(2);
assert_eq!(group.len(), 0);
group.insert(future::ready(12));
assert_eq!(group.len(), 1);Sourcepub fn capacity(&self) -> usize
Available on crate feature alloc only.
pub fn capacity(&self) -> usize
alloc only.Return the capacity of the FutureGroup.
Example
use futures_concurrency::future::FutureGroup;
use futures_lite::stream;
let group = FutureGroup::with_capacity(2);
assert!(group.capacity() >= 2);Sourcepub fn is_empty(&self) -> bool
Available on crate feature alloc only.
pub fn is_empty(&self) -> bool
alloc only.Returns true if there are no futures currently active in the group.
Example
use futures_concurrency::future::FutureGroup;
use std::future;
let mut group = FutureGroup::with_capacity(2);
assert!(group.is_empty());
group.insert(future::ready(12));
assert!(!group.is_empty());Sourcepub fn remove(&mut self, key: Key) -> bool
Available on crate feature alloc only.
pub fn remove(&mut self, key: Key) -> bool
alloc only.Removes a stream from the group. Returns whether the value was present in the group.
Example
use futures_concurrency::future::FutureGroup;
use std::future;
let mut group = FutureGroup::new();
let key = group.insert(future::ready(4));
assert_eq!(group.len(), 1);
group.remove(key);
assert_eq!(group.len(), 0);Sourcepub fn contains_key(&mut self, key: Key) -> bool
Available on crate feature alloc only.
pub fn contains_key(&mut self, key: Key) -> bool
alloc only.Returns true if the FutureGroup contains a value for the specified key.
Example
use futures_concurrency::future::FutureGroup;
use std::future;
let mut group = FutureGroup::new();
let key = group.insert(future::ready(4));
assert!(group.contains_key(key));
group.remove(key);
assert!(!group.contains_key(key));Sourcepub fn reserve(&mut self, additional: usize)
Available on crate feature alloc only.
pub fn reserve(&mut self, additional: usize)
alloc only.Reserves capacity for additional more futures to be inserted.
Does nothing if the capacity is already sufficient.
Example
use futures_concurrency::future::FutureGroup;
use std::future::Ready;
let mut group: FutureGroup<Ready<usize>> = FutureGroup::with_capacity(0);
assert_eq!(group.capacity(), 0);
group.reserve(10);
assert!(group.capacity() >= 10);
// does nothing if capacity is sufficient
group.reserve(5);
assert!(group.capacity() >= 10);Sourceimpl<F> FutureGroup<F>where
F: Future,
impl<F> FutureGroup<F>where
F: Future,
Sourcepub fn insert(&mut self, future: F) -> Keywhere
F: Future,
Available on crate feature alloc only.
pub fn insert(&mut self, future: F) -> Keywhere
F: Future,
alloc only.Insert a new future into the group.
Example
use futures_concurrency::future::FutureGroup;
use std::future;
let mut group = FutureGroup::with_capacity(2);
group.insert(future::ready(12));Sourcepub fn keyed(self) -> Keyed<F>
Available on crate feature alloc only.
pub fn keyed(self) -> Keyed<F>
alloc only.Create a stream which also yields the key of each item.
Example
use futures_concurrency::future::FutureGroup;
use futures_lite::StreamExt;
use std::future;
let mut group = FutureGroup::new();
group.insert(future::ready(2));
group.insert(future::ready(4));
let mut out = 0;
let mut group = group.keyed();
while let Some((_key, num)) = group.next().await {
out += num;
}
assert_eq!(out, 6);Trait Implementations
Sourceimpl<T> Debug for FutureGroup<T>where
T: Debug,
impl<T> Debug for FutureGroup<T>where
T: Debug,
Sourceimpl<T> Default for FutureGroup<T>
impl<T> Default for FutureGroup<T>
Sourcefn default() -> FutureGroup<T>
fn default() -> FutureGroup<T>
Returns the “default value” for a type. Read more
Sourceimpl<F> Extend<F> for FutureGroup<F>where
F: Future,
impl<F> Extend<F> for FutureGroup<F>where
F: Future,
Sourcefn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = F>,
fn extend<T>(&mut self, iter: T)where
T: IntoIterator<Item = F>,
Extends a collection with the contents of an iterator. Read more
Sourcefn extend_one(&mut self, item: A)
fn extend_one(&mut self, item: A)
🔬This is a nightly-only experimental API. (
extend_one)Extends a collection with exactly one element.
Sourcefn extend_reserve(&mut self, additional: usize)
fn extend_reserve(&mut self, additional: usize)
🔬This is a nightly-only experimental API. (
extend_one)Reserves capacity in a collection for the given number of additional elements. Read more
Sourceimpl<F> FromIterator<F> for FutureGroup<F>where
F: Future,
impl<F> FromIterator<F> for FutureGroup<F>where
F: Future,
Sourcefn from_iter<T>(iter: T) -> FutureGroup<F>where
T: IntoIterator<Item = F>,
fn from_iter<T>(iter: T) -> FutureGroup<F>where
T: IntoIterator<Item = F>,
Creates a value from an iterator. Read more
Sourceimpl<F> Stream for FutureGroup<F>where
F: Future,
impl<F> Stream for FutureGroup<F>where
F: Future,
Sourcefn poll_next(
self: Pin<&mut FutureGroup<F>>,
cx: &mut Context<'_>,
) -> Poll<Option<<FutureGroup<F> as Stream>::Item>>
fn poll_next( self: Pin<&mut FutureGroup<F>>, cx: &mut Context<'_>, ) -> Poll<Option<<FutureGroup<F> as Stream>::Item>>
Attempt to pull out the next value of this stream, registering the
current task for wakeup if the value is not yet available, and returning
None if the stream is exhausted. Read moreimpl<'pin, F> Unpin for FutureGroup<F>where
<PinnedFieldsOfHelperStruct<__FutureGroup<'pin, F>> as PinnedFieldsOfHelperTrait>::Actual: Unpin,