Keyed

pub struct Keyed<S>
where S: Stream,
{ /* private fields */ }
Available on crate features nano-alloc and alloc only.
Iterate over items in the stream group with their associated keys.

Methods from Deref<Target = StreamGroup<S>>

pub fn len(&self) -> usize

Return the number of futures currently active in the group.

Example
use futures_concurrency::stream::StreamGroup;
use futures_lite::stream;

let mut group = StreamGroup::with_capacity(2);
assert_eq!(group.len(), 0);
group.insert(stream::once(12));
assert_eq!(group.len(), 1);
pub fn capacity(&self) -> usize

Return the capacity of the StreamGroup.

Example
use futures_concurrency::stream::StreamGroup;
use futures_lite::stream;

let group = StreamGroup::with_capacity(2);
assert!(group.capacity() >= 2);
pub fn is_empty(&self) -> bool

Returns true if there are no futures currently active in the group.

Example
use futures_concurrency::stream::StreamGroup;
use futures_lite::stream;

let mut group = StreamGroup::with_capacity(2);
assert!(group.is_empty());
group.insert(stream::once(12));
assert!(!group.is_empty());
pub fn remove(&mut self, key: Key) -> bool

Removes a stream from the group. Returns whether the value was present in the group.

Example
use futures_lite::stream;
use futures_concurrency::stream::StreamGroup;

let mut group = StreamGroup::new();
let key = group.insert(stream::once(4));
assert_eq!(group.len(), 1);
group.remove(key);
assert_eq!(group.len(), 0);
pub fn contains_key(&mut self, key: Key) -> bool

Returns true if the StreamGroup contains a value for the specified key.

Example
use futures_lite::stream;
use futures_concurrency::stream::StreamGroup;

let mut group = StreamGroup::new();
let key = group.insert(stream::once(4));
assert!(group.contains_key(key));
group.remove(key);
assert!(!group.contains_key(key));
pub fn reserve(&mut self, additional: usize)

Reserves capacity for additional more streams to be inserted. Does nothing if the capacity is already sufficient.

Example
use futures_concurrency::stream::StreamGroup;
use futures_lite::stream::Once;
let mut group: StreamGroup<Once<usize>> = StreamGroup::with_capacity(0);
assert_eq!(group.capacity(), 0);
group.reserve(10);
assert!(group.capacity() >= 10);

// does nothing if capacity is sufficient
group.reserve(5);
assert!(group.capacity() >= 10);
pub fn insert(&mut self, stream: S) -> Key
where S: Stream,

Insert a new stream into the group.

Example
use futures_concurrency::stream::StreamGroup;
use futures_lite::stream;

let mut group = StreamGroup::with_capacity(2);
group.insert(stream::once(12));