Join

Struct Join 

pub struct Join<H, T> {
    pub head: H,
    pub tail: T,
    pub head_done: bool,
    pub tail_done: bool,
}
Available on crate feature nano-alloc only.
A Future that polls two sub-futures to completion.

This is the primitive building block for the join! macro. It stores the completion state of two futures and returns Ready only when both are done.

Fields

head: Htail: Thead_done: booltail_done: bool