TaskNode

Struct TaskNode 

pub struct TaskNode<'curr, 'next> {
    pub future: Pin<Box<dyn Future<Output = ()> + 'curr>>,
    pub interval: u64,
    pub next_run_time: u64,
    pub next: Option<&'next mut TaskNode<'curr, 'next>>,
}
Available on crate feature nano-alloc only.
A node in a linked-list representing an asynchronous task.

Lifetimes

  • 'curr: The lifetime of the future’s internal data.
  • 'next: The lifetime of the reference to the next node in the list.

tip: 'curr is longer than 'next.

Fields

future: Pin<Box<dyn Future<Output = ()> + 'curr>>

The pinned asynchronous computation to be executed.

interval: u64

The execution interval, converted into hardware ticks.

next_run_time: u64

The timestamp (in ticks) when this task should run again.

next: Option<&'next mut TaskNode<'curr, 'next>>

Link to the next task in the executor’s chain.

Implementations

Source

impl<'curr, 'next> TaskNode<'curr, 'next>

pub fn new(future: Pin<Box<dyn Future<Output = ()> + 'curr>>, freq: u64) -> Self

Creates a new TaskNode with a given future and frequency.

Note: freq is initially the user-requested frequency and is recalculated into an interval when added to an [Executor].