pub struct Timeout<'bemly_, Content> { /* private fields */ }Available on crate feature
nano-alloc only.Expand description
A wrapper that adds a time limit to a Future.
If the internal future does not complete before the deadline (in hardware ticks),
it returns Err(()). Otherwise, it returns Ok(Output).
Examples
use uefi_async::nano_alloc::time::Timeout;
async fn calc_1() {}
async fn calc_2() {
match Box::pin(calc_2()).timeout(Duration::from_secs(2).as_secs()).await { _ => () }
match Timeout::new_pin(Box::pin(calc_2()), 500).await { _ => () }
match Timeout::new(calc_1(), 300).await { _ => () }
match calc_2().timeout(500).await { Ok(_) => {}, Err(_) => {} }
}Implementations