Module no_alloc

Module no_alloc 

Available on crate feature static only.
Static task management module.

This module provides a mechanism for running the executor without a dynamic memory allocator, utilizing static memory or stack-allocated task nodes. Useful for highly constrained environments.

Modules

config
executor
lifo
This code is inspired by the approach in this algorithm Rust crate: st3 lifo queue.
task
This code is inspired by the approach in this embedded Rust crate: embassy-executor.
waker