Available on crate feature
static only.Expand description
Static task management module.
This module provides a mechanism for running the executor without a dynamic memory allocator, utilizing static memory or stack-allocated task nodes. Useful for highly constrained environments.